@@ -30,9 +30,13 @@ import os
 # import re
 import tempfile
 
-from rattail.util import load_object, pretty_quantity, progress_loop
+import six
+
+from rattail.util import (load_object, load_entry_points,
+                          OrderedDict, progress_loop, pretty_quantity)
 from rattail.files import temp_path
 from rattail.mail import send_email
+from rattail.config import parse_list
 
 
 class AppHandler(object):
@@ -62,6 +66,33 @@ class AppHandler(object):
     def __init__(self, config):
         self.config = config
 
+        # app may not use the db layer, but if so we set the model
+        try:
+            self.model = config.get_model()
+        except:
+            pass
+
+    def get_title(self, default=None):
+        return self.config.app_title(default=default)
+
+    def load_entry_points(self, group, **kwargs):
+        return load_entry_points(group, **kwargs)
+
+    def get_active_stores(self, session, **kwargs):
+        """
+        Returns the list of "active"
+        :class:`~rattail.db.model.stores:Store` records.
+        """
+        import sqlalchemy as sa
+
+        model = self.model
+        return session.query(model.Store)\
+                      .filter(sa.or_(
+                          model.Store.archived == False,
+                          model.Store.archived == None))\
+                      .order_by(model.Store.id)\
+                      .all()
+
     def get_autocompleter(self, key, **kwargs):
         """
         Returns a new :class:`~rattail.autocomplete.base.Autocompleter`
@@ -154,6 +185,167 @@ class AppHandler(object):
     # TODO: is it helpful to expose this? or more confusing?
     get_mail_handler = get_email_handler
 
+    def get_all_import_handlers(self, ignore_errors=True, sort=False,
+                                **kwargs):
+        """
+        Returns *all* Import/Export Handler classes which are known to
+        exist, i.e.  all which are registered via ``setup.py`` for the
+        various packages installed.
+
+        This means it will include both "designated" handlers as well
+        as non-designated.  See
+        :meth:`get_designated_import_handlers()` if you only want the
+        designated ones.
+
+        Note that this will return the *Handler classes* and not
+        *handler instances*.
+
+        :param ignore_errors: Normally any errors which come up during
+           the loading process are ignored.  Pass ``False`` here to
+           force errors to raise, e.g. if you are not seeing the
+           results you expect.
+
+        :param sort: If you like the results can be sorted with a
+           simple key based on "Source -> Target" labels.
+
+        :returns: List of all registered Import/Export Handler classes.
+        """
+        handlers = self.load_entry_points('rattail.importing',
+                                          ignore_errors=ignore_errors)
+        handlers = list(handlers.values())
+
+        if sort:
+            handlers.sort(key=lambda h: (h.get_generic_host_title(),
+                                         h.get_generic_local_title()))
+
+        return handlers
+
+    def get_designated_import_handlers(self, with_alternates=False, **kwargs):
+        """
+        Returns all "designated" import/export handler instances.
+
+        Each "handler type key" can have at most one Handler class
+        which is "designated" in the config.  This method collects all
+        registered handlers and then sorts out which one is
+        designated, for each type key, ultimately returning only the
+        designated ones.
+
+        Note that this will return the *handler instances* and not
+        *Handler classes*.
+
+        If you have a type key and just need its designated handler,
+        see :meth:`get_designated_import_handler()`.
+
+        See also :meth:`get_all_import_handlers()` if you need all
+        registered Handler classes.
+
+        :param with_alternates: If you specify ``True`` here then each
+           designated handler returned will have an extra attribute
+           named ``alternate_handlers``, which will be a list of the
+           other "available" (registered) handlers which match the
+           designated handler's type key.
+
+           This is probably most / only useful for the Configuration
+           UI, to allow admin to change which is designated.
+
+        :returns: List of all designated import/export handler instances.
+        """
+        grouped = OrderedDict()
+        for Handler in self.get_all_import_handlers(**kwargs):
+            key = Handler.get_key()
+            grouped.setdefault(key, []).append(Handler)
+
+        def find_designated(key, group):
+            spec = self.get_designated_import_handler_spec(key)
+            if spec:
+                for Handler in group:
+                    if Handler.get_spec() == spec:
+                        return Handler
+
+            if len(group) == 1:
+                return group[0]
+
+            raise RuntimeError("multiple ({}) handlers available but none designated for: {}".format(
+                len(group), group[0].get_key()))
+
+        designated = []
+        for key, group in six.iteritems(grouped):
+            Handler = find_designated(key, group)
+            if Handler:
+                # nb. we must instantiate here b/c otherwise if we
+                # assign the `alternate_handlers` attr onto the class,
+                # it can affect subclasses as well.  not so with
+                # instances though
+                handler = Handler(self.config)
+                if with_alternates:
+                    handler.alternate_handlers = [H for H in group
+                                                  if H is not Handler]
+                designated.append(handler)
+
+        return designated
+
+    def get_designated_import_handler(self, key, require=False, **kwargs):
+        """
+        Return the designated import/export handler instance, per the
+        given handler type key.
+
+        See also :meth:`get_designated_import_handlers()` if you want
+        the full set of designated handlers.
+
+        :param key: A "handler type key", e.g.
+           ``'to_rattail.from_rattail.import'``.
+
+        :param require: Specify ``True`` here if you want an error to
+           be raised should no handler be found.
+
+        :returns: The import/export handler instance corresponding to
+           the given key.  If no handler can be found, then ``None``
+           is returned, unless ``require`` param is true, in which
+           case error is raised.
+        """
+        # first try to fetch the handler per designated spec
+        spec = self.get_designated_import_handler_spec(key, require=require,
+                                                       **kwargs)
+        if spec:
+            Handler = load_object(spec)
+            return Handler(self.config)
+
+        # nothing was designated, so leverage logic which already
+        # sorts out which handler is "designated" for given key
+        designated = self.get_designated_import_handlers(
+            ignore_errors=not require)
+        for handler in designated:
+            if handler.get_key() == key:
+                return handler
+
+        if require:
+            raise RuntimeError("Cannot locate designated handler for key: {}".format(
+                key))
+
+    def get_designated_import_handler_spec(self, key, require=False, **kwargs):
+        spec = self.config.get('rattail.importing',
+                               '{}.handler'.format(key))
+        if spec:
+            return spec
+
+        legacy_setting = self.config.get('rattail.importing',
+                                         '{}.legacy_handler_setting'.format(key))
+        if legacy_setting:
+            legacy_setting = parse_list(legacy_setting)
+            if len(legacy_setting) == 2:
+                section, option = legacy_setting
+                spec = self.config.get(section, option)
+                if spec:
+                    return spec
+
+        spec = self.config.get('rattail.importing',
+                               '{}.default_handler'.format(key))
+        if spec:
+            return spec
+
+        if require:
+            raise RuntimeError("Cannot locate handler spec for key: {}".format(key))
+
     def get_membership_handler(self, **kwargs):
         """
         Returns a reference to the configured Membership Handler.
@@ -192,6 +384,13 @@ class AppHandler(object):
             self.report_handler = get_report_handler(self.config, **kwargs)
         return self.report_handler
 
+    def get_problem_report_handler(self, **kwargs):
+        if not hasattr(self, 'problem_report_handler'):
+            from rattail.problems import get_problem_report_handler
+            self.problem_report_handler = get_problem_report_handler(
+                self.config, **kwargs)
+        return self.problem_report_handler
+
     def progress_loop(self, *args, **kwargs):
         return progress_loop(*args, **kwargs)
 
