@@ -71,6 +71,11 @@ class DataSync(Subcommand):
         wait = subparsers.add_parser('wait', help="Wait for changes to be processed")
         wait.set_defaults(subcommand='wait')
 
+        remove_settings = subparsers.add_parser(
+            'remove-settings',
+            help="Remove all datasync settings from the DB")
+        remove_settings.set_defaults(subcommand='remove-settings')
+
         parser.add_argument('-p', '--pidfile', metavar='PATH', default='/var/run/rattail/datasync.pid',
                             help="Path to PID file.")
         parser.add_argument('--daemonize', action='store_true', default=True, # TODO: should default to False
@@ -108,6 +113,9 @@ class DataSync(Subcommand):
         elif args.subcommand == 'collectd':
             self.collectd(args)
 
+        elif args.subcommand == 'remove-settings':
+            self.remove_settings(args)
+
         else: # manage the daemon
             daemon = DataSyncDaemon(args.pidfile, config=self.config)
             if args.subcommand == 'stop':
@@ -248,7 +256,9 @@ class DataSync(Subcommand):
                              total, now=now)
 
         # stale changes in queue
-        timeout = 90 # minutes
+        timeout = self.config.getint('rattail.datasync',
+                                     'collectd.changes_stale_timeout',
+                                     default=15) # minutes
         cutoff = make_utc() - datetime.timedelta(seconds=60 * timeout)
         stale = session.query(model.DataSyncChange)\
                        .filter(model.DataSyncChange.obtained < cutoff)\
@@ -287,3 +297,14 @@ class DataSync(Subcommand):
             value)
 
         sys.stdout.write(msg)
+
+    def remove_settings(self, args):
+        """
+        Remove all datasync settings from the DB
+        """
+        from rattail.datasync.util import purge_datasync_settings
+
+        session = self.app.make_session()
+        purge_datasync_settings(self.config, session)
+        session.commit()
+        session.close()
