@@ -44,25 +44,45 @@ class ImportSubcommand(Subcommand):
     """
     Base class for subcommands which use the (new) data importing system.
     """
+    handler_key = None
+
+    # TODO: should remove this? or perhaps is still useful for simple
+    # custom commands to use, which need not worry about inheritance
+    # and alternate handlers available etc.
     handler_spec = None
 
     # TODO: move this into Subcommand or something..
     parent_name = None
     def __init__(self, *args, **kwargs):
+
+        # TODO: should remove this? or perhaps is still useful for
+        # simple custom commands to use, which need not worry about
+        # inheritance and alternate handlers available etc.
         if 'handler_spec' in kwargs:
             self.handler_spec = kwargs.pop('handler_spec')
+
         super(ImportSubcommand, self).__init__(*args, **kwargs)
         if self.parent:
             self.parent_name = self.parent.name
 
     def get_handler_factory(self, **kwargs):
         """
-        Subclasses must override this, and return a callable that creates an
-        import handler instance which the command should use.
+        Should return a Handler factory (e.g. class) which will later
+        be called to create a handler instance.
         """
+        # TODO: should remove this? or perhaps is still useful for
+        # simple custom commands to use, which need not worry about
+        # inheritance and alternate handlers available etc.
         if self.handler_spec:
             return load_object(self.handler_spec)
-        raise NotImplementedError
+
+        if self.handler_key:
+            handler = self.app.get_designated_import_handler(self.handler_key)
+            return type(handler)
+
+        raise RuntimeError("Cannot locate a handler to use!  You "
+                           "should probably define `{}.handler_key`"
+                           "".format(self.__class__.__name__))
 
     def get_handler(self, **kwargs):
         """
@@ -103,12 +123,6 @@ class ImportSubcommand(Subcommand):
         doc = ("Which data models to import.  If you specify any, then only "
                "data for those models will be imported.  If you do not specify "
                "any, then all *default* models will be imported.")
-        try:
-            handler = self.get_handler()
-        except NotImplementedError:
-            pass
-        else:
-            doc += "  Supported models are: ({})".format(', '.join(handler.get_importer_keys()))
         parser.add_argument('models', nargs='*', metavar='MODEL', help=doc)
 
         # make batches
@@ -214,10 +228,10 @@ class ImportSubcommand(Subcommand):
                             "Note that this flag is ignored if --make-batches is specified.")
 
     def run(self, args):
-        log.info("begin `%s %s` for data models: %s",
-                 self.parent_name,
-                 self.name,
-                 ', '.join(args.models) if args.models else "(ALL)")
+        log.debug("begin `%s %s` for data models: %s",
+                  self.parent_name,
+                  self.name,
+                  ', '.join(args.models) if args.models else "(ALL)")
 
         handler = self.get_handler(args=args)
         models = args.models or handler.get_default_keys()
@@ -299,16 +313,7 @@ class ImportCSV(ImportFileSubcommand):
     """
     name = 'import-csv'
     description = __doc__.strip()
-    default_handler_spec = 'rattail.importing.csv:FromCSVToRattail'
-
-    def get_handler_factory(self, **kwargs):
-        if self.config:
-            spec = self.config.get('rattail.importing', 'csv.handler',
-                                   default=self.default_handler_spec)
-        else:
-            # just use default, for sake of cmd line help
-            spec = self.default_handler_spec
-        return load_object(spec)
+    handler_key = 'to_rattail.from_csv.import'
 
 
 class ImportIFPS(ImportFileSubcommand):
@@ -317,16 +322,7 @@ class ImportIFPS(ImportFileSubcommand):
     """
     name = 'import-ifps'
     description = __doc__.strip()
-    default_handler_spec = 'rattail.importing.ifps:FromIFPSToRattail'
-
-    def get_handler_factory(self, **kwargs):
-        if self.config:
-            spec = self.config.get('rattail.importing', 'ifps.handler',
-                                   default=self.default_handler_spec)
-        else:
-            # just use default, for sake of cmd line help
-            spec = self.default_handler_spec
-        return load_object(spec)
+    handler_key = 'to_rattail.from_ifps.import'
 
 
 class ExportFileSubcommand(ImportSubcommand):
@@ -357,16 +353,7 @@ class ExportCSV(ExportFileSubcommand):
     """
     name = 'export-csv'
     description = __doc__.strip()
-    default_handler_spec = 'rattail.importing.exporters:FromRattailToCSV'
-
-    def get_handler_factory(self, **kwargs):
-        if self.config:
-            spec = self.config.get('rattail.exporting', 'csv.handler',
-                                   default=self.default_handler_spec)
-        else:
-            # just use default, for sake of cmd line help
-            spec = self.default_handler_spec
-        return load_object(spec)
+    handler_key = 'to_csv.from_rattail.export'
 
 
 class ExportRattail(ImportSubcommand):
@@ -375,18 +362,9 @@ class ExportRattail(ImportSubcommand):
     """
     name = 'export-rattail'
     description = __doc__.strip()
-    default_handler_spec = 'rattail.importing.rattail:FromRattailToRattailExport'
+    handler_key = 'to_rattail.from_rattail.export'
     default_dbkey = 'host'
 
-    def get_handler_factory(self, **kwargs):
-        if self.config:
-            spec = self.config.get('rattail.exporting', 'rattail.handler',
-                                   default=self.default_handler_spec)
-        else:
-            # just use default, for sake of cmd line help
-            spec = self.default_handler_spec
-        return load_object(spec)
-
     def add_parser_args(self, parser):
         super(ExportRattail, self).add_parser_args(parser)
         parser.add_argument('--dbkey', metavar='KEY', default=self.default_dbkey,
@@ -404,18 +382,6 @@ class ImportToRattail(ImportSubcommand):
     """
     Generic base class for commands which import *to* a Rattail system.
     """
-    # subclass must set these!
-    handler_key = None
-    default_handler_spec = None
-
-    def get_handler_factory(self, **kwargs):
-        if self.config:
-            spec = self.config.get('rattail.importing', '{}.handler'.format(self.handler_key),
-                                   default=self.default_handler_spec)
-        else:
-            # just use default, for sake of cmd line help
-            spec = self.default_handler_spec
-        return load_object(spec)
 
 
 class ImportRattail(ImportToRattail):
@@ -424,8 +390,7 @@ class ImportRattail(ImportToRattail):
     """
     name = 'import-rattail'
     description = __doc__.strip()
-    handler_key = 'rattail'
-    default_handler_spec = 'rattail.importing.rattail:FromRattailToRattailImport'
+    handler_key = 'to_rattail.from_rattail.import'
     accepts_dbkey_param = True
 
     def add_parser_args(self, parser):
@@ -450,8 +415,7 @@ class ImportRattailBulk(ImportRattail):
     """
     name = 'import-rattail-bulk'
     description = __doc__.strip()
-    handler_key = 'rattail_bulk'
-    default_handler_spec = 'rattail.importing.rattail_bulk:BulkFromRattailToRattail'
+    handler_key = 'to_rattail.from_rattail_bulk.import'
 
 
 class ImportSampleData(ImportToRattail):
@@ -460,8 +424,7 @@ class ImportSampleData(ImportToRattail):
     """
     name = 'import-sample'
     description = __doc__.strip()
-    handler_key = 'sample'
-    default_handler_spec = 'rattail.importing.sample:FromSampleToRattail'
+    handler_key = 'to_rattail.from_sample.import'
 
 
 class ImportVersions(ImportRattail):
@@ -470,8 +433,7 @@ class ImportVersions(ImportRattail):
     """
     name = 'import-versions'
     description = __doc__.strip()
-    handler_key = 'versions'
-    default_handler_spec = 'rattail.importing.versions:FromRattailToRattailVersions'
+    handler_key = 'to_rattail_versions.from_rattail.import'
     accepts_dbkey_param = False
     default_comment = "import catch-up versions"
 
