@@ -118,7 +118,7 @@ class RattailConfig(object):
         else: # PY2
             self.parser = configparser.SafeConfigParser()
         for path in files:
-            self.read_file(path)
+            self.read_file(path, require=True)
         self.usedb = usedb
         if self.usedb is None:
             self.usedb = self.getbool('rattail.config', 'usedb', usedb=False, default=False)
