@@ -64,17 +64,27 @@ class Role(Base):
     """)
 
     sync_me = sa.Column(sa.Boolean(), nullable=True, doc="""
-    Flag indicating that this Role (and its user-ship, and
-    permissions) should be synced across all nodes.
+    Flag indicating that the Role - its primary attributes, and list
+    of permissions - should be synced across all nodes.
 
-    So if set, when the role changes at one node that change should
-    propagate to all other nodes.  This includes "proper" changes e.g.
-    to the role name, but also when any users are added to or removed
-    from the role, that fact also should propagate.  Additionally,
-    when permissions are granted to or revoked from the role, that
-    should propagate.
+    So if set, when the role changes at one node then that change
+    should propagate to all other nodes.
 
-    See also :attr:`node_type`.
+    Note that this does *not* include the user list by default; see
+    :attr:`sync_users` to add that.
+
+    Note that if this flag is set, the role will be synced to *all*
+    nodes regardless of node type.  See also :attr:`node_type`.
+    """)
+
+    sync_users = sa.Column(sa.Boolean(), nullable=True, doc="""
+    Flag indicating that the user list for the role should be synced
+    across all nodes.  This has no effect unless :attr:`sync_me` is
+    also set.
+
+    Note that if this flag is set, the role's user list will be synced
+    to *all* nodes regardless of node type.  See also
+    :attr:`node_type`.
     """)
 
     node_type = sa.Column(sa.String(length=100), nullable=True, doc="""
@@ -83,10 +93,11 @@ class Role(Base):
 
     If set, this value must match a node's configured type, or else it
     will be ignored by that node.  See also
-    :meth:`~rattail.config.RattailConfig.node_type()`.  If there is no
-    value set for this field then the role will be honored by all
-    nodes in which it exists (which is just one unless ``sync_me`` is
-    set, in which case all nodes would have it).
+    :meth:`~rattail.config.RattailConfig.node_type()` for how a node's
+    type is determined.  If there is no value set for this field then
+    the role will be honored by all nodes in which it exists (which is
+    just one unless ``sync_me`` is set, in which case all nodes would
+    have it).
 
     It is useful in combination with ``sync_me`` in that it allows a
     certain role to be "global" (synced) and yet only be "effective"
