@@ -249,6 +249,15 @@ PENDING_CUSTOMER_STATUS = OrderedDict([
 ])
 
 
+PENDING_PRODUCT_STATUS_PENDING          = 1
+PENDING_PRODUCT_STATUS_READY            = 2
+
+PENDING_PRODUCT_STATUS = OrderedDict([
+    (PENDING_PRODUCT_STATUS_PENDING,    "pending"),
+    (PENDING_PRODUCT_STATUS_READY,      "ready"),
+])
+
+
 PHONE_TYPE_HOME                 = 'home'
 PHONE_TYPE_MOBILE               = 'mobile'
 PHONE_TYPE_OTHER                = 'other'
