@@ -154,6 +154,12 @@ class ExcelReaderXLSX(object):
                       message="Reading data from Excel file")
         return rows
 
+    # TODO: this is here just for method signature compatibility with
+    # the older xlrd-based reader above.  maybe should just deprecate
+    # and/or remove it though
+    def parse_date(self, value, fmt=None):
+        return value
+
 
 class ExcelWriter(object):
     """
