@@ -45,6 +45,9 @@ from rattail.config import parse_bool
 
 class FromCSVToSQLAlchemyMixin(object):
 
+    host_key = 'csv'
+    generic_host_title = "CSV"
+
     # subclass must define this
     ToParent = None
 
