@@ -44,6 +44,8 @@ class FromRattailHandler(FromSQLAlchemyHandler):
     """
     Base class for import handlers which target a Rattail database on the local side.
     """
+    host_key = 'rattail'
+    generic_host_title = "Rattail"
 
     @property
     def host_title(self):
@@ -57,6 +59,8 @@ class ToRattailHandler(ToSQLAlchemyHandler):
     """
     Base class for import handlers which target a Rattail database on the local side.
     """
+    generic_local_title = "Rattail"
+    local_key = 'rattail'
 
     @property
     def local_title(self):
