@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2019 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -97,6 +97,27 @@ class ProblemReportHandler(object):
                     matches.append(report)
         return matches
 
+    def get_problem_report(self, system_key, problem_key, **kwargs):
+        """
+        Return a specific problem report, identified by the
+        system/problem key pair.
+
+        :param system_key: System key, part of the identifier.
+
+        :param problem_key: Problem key, part of the identifier.
+
+        :returns: A specific :class:`~ProblemReport` class, if a match
+           was found, otherwise ``None``.
+        """
+        reports = self.get_problem_reports(systems=[system_key],
+                                           problems=[problem_key])
+        if reports:
+            if len(reports) > 1:
+                raise RuntimeError("Multiple problem reports defined "
+                                   "for key: {}.{}".format(
+                                       system_key, problem_key))
+            return reports[0]
+
     def organize_problem_reports(self, reports):
         """
         Returns a nested dict with the given problem reports.
@@ -147,6 +168,14 @@ class ProblemReportHandler(object):
         log.info("found %s problems", len(problems))
         if problems:
             self.send_problem_report(report, problems)
+        return problems
+
+    def get_email_key(self, report):
+        if report.email_key:
+            return report.email_key
+
+        return '{}_problems_{}'.format(report.system_key,
+                                       report.problem_key)
 
     def send_problem_report(self, report, problems):
         """
@@ -161,11 +190,7 @@ class ProblemReportHandler(object):
             'render_time': self.render_time,
         })
 
-        email_key = report.email_key
-        if not email_key:
-            email_key = '{}_problems_{}'.format(
-                report.system_key, report.problem_key)
-
+        email_key = self.get_email_key(report)
         send_email(self.config, email_key, context,
                    default_subject=report.problem_title)
 
