@@ -180,21 +180,41 @@ class ProductsHandler(GenericHandler):
 
         return products
 
+    def get_url(self, product, **kwargs):
+        """
+        Return the Tailbone "view" URL for the given product.
+        """
+        base_url = self.config.base_url()
+        if base_url:
+            return '{}/products/{}'.format(base_url, product.uuid)
+
     def get_image_url(self, product=None, upc=None, **kwargs):
         """
         Return the preferred image URL for the given UPC or product.
         """
-        # we prefer the "image on file" if available
-        if product and product.image:
-            url = self.config.base_url()
-            if url:
-                return '{}/products/{}/image'.format(url, product.uuid)
+        base_url = self.config.base_url()
 
-        # fallback to the POD image, if available
-        if product and not upc:
-            upc = product.upc
-        if upc:
-            return self.get_pod_image_url(upc)
+        # we prefer the "image on file" if available
+        if base_url and product and product.image:
+            return '{}/products/{}/image'.format(base_url, product.uuid)
+
+        # and if this product is a pack item, then we prefer the unit
+        # item image as fallback, if available
+        if base_url and product and product.is_pack_item():
+            unit = product.unit
+            if unit and unit.image:
+                return '{}/products/{}/image'.format(base_url, unit.uuid)
+
+        # fallback to the POD image, if available and so configured
+        if self.config.getbool('tailbone', 'products.show_pod_image',
+                               default=False):
+            if product and not upc:
+                upc = product.upc
+            if upc:
+                return self.get_pod_image_url(upc)
+
+        if base_url:
+            return '{}/tailbone/img/product.png'.format(base_url)
 
     def get_pod_image_url(self, upc, **kwargs):
         """
